# Change log

## `v0.2.0` - 2023-03-28

### Improvements
- `PyscfCalculation`: Use `PrefixLoader` for template environment loader [[#12]](https://github.com/microsoft/aiida-pyscf/pull/12)
- `PyscfCalculation`: Improve white-space in rendered script [[#13]](https://github.com/microsoft/aiida-pyscf/pull/13)


## `v0.1.0` - 2023-03-27

First release of the package.
